<?php
/**
 * @file
 * Admin forms for Paypal API
 */
/**
 *
 * Form builder for the system settings form.
 */
function paypal_api_settings_form() {
  $settings = paypal_api_settings();

  $form = array(
    'business' => array(
      '#type'		        => 'textfield',
      '#title'	        => t("Your PayPal ID or an email address associated with your PayPal account"),
      '#description'	  => t("If you leave this blank, the value must be provided by the module creating the transaction, or the site email address will be used."),
      '#default_value'	=> $settings['business']
    ),
    'create_user'	=> array(
      '#type'		        => 'checkbox',
      '#title'	        => t("Allow Paypal API to automatically create user accounts"),
      '#default_value'	=> $settings['create_user'],
      '#description'	  => t("If this box is checked, when an anonymous user attempts to pay for content, a user account will be created automatically for them once their payment has gone through.  The user will be assigned to the 'authenticated' role, though you may override this behavior using the appropriate Rule.")
    ),
    'currency_code'	=> array(
      '#type'		        => 'select',
      '#title'	        => t("Default currency"),
      '#default_value'	=> $settings['currency_code'],
      '#options'        => paypal_api_currencies(),
      '#description'	  => t("The default currency for payments.  This may be altered by a module on a per transaction basis.")
    ),
    'developer_settings' => array(
      '#type'		      => 'fieldset',
      '#title'	      => t("Developer settings"),
      '#collapsible'	=> TRUE,
      '#collapsed'    => (!$settings['sandbox'] && !$settings['domain']),

      'sandbox'	=> array(
        '#type'		        => 'checkbox',
        '#title'	        => t("Use the Paypal sandbox"),
        '#default_value'	=> $settings['sandbox'],
        '#description'	  => t("Use the Paypal sandbox to test the system.  This requires that you create a developer account and use buttons you've created inside the sandbox for testing.")
      ),
      'domain'	=> array(
        '#type'		        => 'textfield',
        '#title'	        => t("Local domain name"),
        '#default_value'	=> $settings['domain'],
        '#description'	  => t("Specify the domain name to use for IPN callbacks, success and cancellation pages.  Leave this blank to use your server's domain '!server_name'.  You should only need to set this if you are behind a firewall or have port forwarding set up to a test machine.", array('!server_name' => $_SERVER['SERVER_NAME']))
      )
    ),
    'submit'  => array(
      '#type'		=> 'submit',
      '#value'	=> t("Save these settings")
    )
  );

  return $form;
}

/**
 *
 * Submit handler for the system settings form
 *
 * @param $form
 * @param $form_values
 */
function paypal_api_settings_form_submit($form, &$form_values) {
  $settings = paypal_api_settings();

  foreach (array_keys($settings) as $field) {
    $settings[$field] = $form_values['values'][$field];
  }
  variable_set('paypal_api', $settings);

  drupal_set_message(t("Paypal API settings have been updated."), 'status');
}
